==> v-sim_3.4.0.3.orig.tar.gz: v_sim-3.4.0.3/src/panelModules/panelMap.h <==
/*   EXTRAITS DE LA LICENCE
	Copyright CEA, contributeurs : Luc BILLARD, Damien
	CALISTE, Olivier D'Astier, laboratoire L_Sim, (2001-2005)
  
	Adresses ml :
	BILLARD, non joignable par ml ;
	CALISTE, damien P caliste AT cea P fr.
	D'ASTIER, dastier AT iie P cnam P fr.

	Ce logiciel est un programme informatique servant  visualiser des
	structures atomiques dans un rendu pseudo-3D. 

	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
	respectant les principes de diffusion des logiciels libres. Vous pouvez
	utiliser, modifier et/ou redistribuer ce programme sous les conditions
	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
	sur le site "http://www.cecill.info".

	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
	pris connaissance de la licence CeCILL, et que vous en avez accept les
	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
*/

/*   LICENCE SUM UP
	Copyright CEA, contributors : Luc BILLARD and Damien
	CALISTE and Olivier D'Astier, laboratoire L_Sim, (2001-2005)

	E-mail addresses :
	BILLARD, not reachable any more ;
	CALISTE, damien P caliste AT cea P fr.
	D'ASTIER, dastier AT iie P cnam P fr.

	This software is a computer program whose purpose is to visualize atomic
	configurations in 3D.

	This software is governed by the CeCILL  license under French law and
	abiding by the rules of distribution of free software.  You can  use, 
	modify and/ or redistribute the software under the terms of the CeCILL
	license as circulated by CEA, CNRS and INRIA at the following URL
	"http://www.cecill.info". 

	The fact that you are presently reading this means that you have had
	knowledge of the CeCILL license and that you accept its terms. You can
	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
*/

#ifndef PANELMAP_H
#define PANELMAP_H

#include <extraGtkFunctions/gtk_toolPanelWidget.h>

/**
 * panelMapInit:
 *
 * Should be used in the list declared in externalModules.h to be loaded by
 * V_Sim on start-up. This routine will create the #ToolPanel where
 * the coloured map stuff can be done, such as choosing a plane,
 * associating a scalar field...
 *
 * Returns: a newly created #ToolPanel object.
 */
ToolPanel* panelMapInit();

/**
 * panelMapSet:
 * @planeId: a entry for the plane combobox ;
 * @scalarFieldId: a entry for the scalar field combobox ;
 * @shadeId: a entry for the shade combobox.
 *
 * Change the values of the three combobox of this panel.
 */
void panelMapSet(guint planeId, guint scalarFieldId, guint shadeId);
/**
 * panelMapSet_logScale:
 * @logScale: the status.
 *
 * Check or uncheck if the logscale is to be used.
 */
void panelMapSet_logScale(gboolean logScale);
/**
 * panelMapSet_nIsoLines:
 * @nIsoLines: a value.
 *
 * Change the number of drawn isolines.
 */
void panelMapSet_nIsoLines(guint nIsoLines);
#endif

==> v-sim_3.5.1.orig.tar.gz: v_sim-3.5.1/src/panelModules/panelMap.h <==
/*   EXTRAITS DE LA LICENCE
	Copyright CEA, contributeurs : Luc BILLARD, Damien
	CALISTE, Olivier D'Astier, laboratoire L_Sim, (2001-2005)
  
	Adresses ml :
	BILLARD, non joignable par ml ;
	CALISTE, damien P caliste AT cea P fr.
	D'ASTIER, dastier AT iie P cnam P fr.

	Ce logiciel est un programme informatique servant  visualiser des
	structures atomiques dans un rendu pseudo-3D. 

	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
	respectant les principes de diffusion des logiciels libres. Vous pouvez
	utiliser, modifier et/ou redistribuer ce programme sous les conditions
	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
	sur le site "http://www.cecill.info".

	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
	pris connaissance de la licence CeCILL, et que vous en avez accept les
	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
*/

/*   LICENCE SUM UP
	Copyright CEA, contributors : Luc BILLARD and Damien
	CALISTE and Olivier D'Astier, laboratoire L_Sim, (2001-2005)

	E-mail addresses :
	BILLARD, not reachable any more ;
	CALISTE, damien P caliste AT cea P fr.
	D'ASTIER, dastier AT iie P cnam P fr.

	This software is a computer program whose purpose is to visualize atomic
	configurations in 3D.

	This software is governed by the CeCILL  license under French law and
	abiding by the rules of distribution of free software.  You can  use, 
	modify and/ or redistribute the software under the terms of the CeCILL
	license as circulated by CEA, CNRS and INRIA at the following URL
	"http://www.cecill.info". 

	The fact that you are presently reading this means that you have had
	knowledge of the CeCILL license and that you accept its terms. You can
	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
*/

#ifndef PANELMAP_H
#define PANELMAP_H

#include <extraGtkFunctions/gtk_toolPanelWidget.h>
#include <coreTools/toolMatrix.h>

/**
 * panelMapInit:
 *
 * Should be used in the list declared in externalModules.h to be loaded by
 * V_Sim on start-up. This routine will create the #ToolPanel where
 * the coloured map stuff can be done, such as choosing a plane,
 * associating a scalar field...
 *
 * Returns: a newly created #ToolPanel object.
 */
ToolPanel* panelMapInit();

/**
 * panelMapSet:
 * @planeId: a entry for the plane combobox ;
 * @scalarFieldId: a entry for the scalar field combobox ;
 * @shadeId: a entry for the shade combobox.
 *
 * Change the values of the three combobox of this panel.
 *
 * Since: 3.4
 */
void panelMapSet(guint planeId, guint scalarFieldId, guint shadeId);
/**
 * panelMapSet_scale:
 * @scale: the status.
 *
 * Set the scaling method.
 *
 * Since: 3.4
 */
void panelMapSet_scale(matrix_scaleflag scale);
/**
 * panelMapSet_nIsoLines:
 * @nIsoLines: a value.
 *
 * Change the number of drawn isolines.
 *
 * Since: 3.4
 */
void panelMapSet_nIsoLines(guint nIsoLines);
/**
 * panelMapSet_isoLinesColor:
 * @color: an RGB value (can be NULL).
 *
 * Change the colour of drawn isolines. If @color is NULL, then the
 * specific colour is unchecked and inversed colours are used.
 *
 * Since: 3.5
 */
void panelMapSet_isoLinesColor(float *color);
void panelMapSet_precision(guint prec);
#endif
